@@ -22,7 +22,8 @@ possible flags
 --release                  only compile for release
 --verbose_make             generate verbose makefiles
 --skip_external_links      do not check documentation external links
---suppress_spell_warnings  do not check for documentaiton spelling errors
+--skip_check_copy          do not check copyright messages
+--suppress_spell_warnings  do not check for documentation spelling errors
 EOF
       exit 0
    fi
@@ -32,6 +33,7 @@ fi
 build_type='mixed'
 verbose_make='no'
 skip_external_links='no'
+skip_check_copy='no'
 suppress_spell_warnings='no'
 while [ $# != 0 ]
 do
@@ -57,6 +59,10 @@ do
       skip_external_links='yes'
       ;;
 
+      --skip_check_copy)
+      skip_check_copy='yes'
+      ;;
+
       --suppress_spell_warnings)
       suppress_spell_warnings='yes'
       ;;
@@ -111,7 +117,7 @@ echo_log_eval() {
    then
       if $sed $top_srcdir/check_all.tmp \
          -e '/temp_file.cpp:.*warning.*tmpnam/d' \
-         | grep ': *warning *:'
+         | $grep ': *warning *:'
       then
          warning='yes'
       fi
@@ -123,7 +129,7 @@ echo_log_eval() {
          -e '/independent.hpp:10[0-9]:.*warning.*outside array bounds/d' \
          -e '/base_alloc.hpp:143:.*warning.*may be used uninitialized/d' \
          -e '/abs_min_quad.hpp:424:.*bound.*exceeds maximum/d' \
-         | grep ': *warning *:'
+         | $grep ': *warning *:'
       then
          warning='yes'
       fi
@@ -286,7 +292,7 @@ then
 fi
 #
 # prefix
-# absoute prefix where optional packages are installed
+# absolute prefix where optional packages are installed
 eval `$grep '^prefix=' bin/get_optional.sh`
 if [[ "$prefix" =~ ^[^/] ]]
 then
@@ -299,6 +305,16 @@ then
    exit 1
 fi
 #
+# typos
+if which typos >& /dev/null
+then
+   if ! typos
+   then
+      echo 'check_all: see typos errors above'
+      exit 1
+   fi
+fi
+#
 # check_version
 if echo $version | $grep '[0-9]\{4\}0000[.]' > /dev/null
 then
@@ -311,14 +327,19 @@ fi
 # bin/check_*.sh
 # Run automated checks for the form bin/check_*.sh with a few exceptions.
 list=$(
-   ls bin/check_* | sed \
+   ls bin/check_* | $sed \
    -e '/check_all.sh/d' \
    -e '/check_doxygen.sh/d' \
    -e '/check_install.sh/d' \
+   -e '/check_copy.sh/d' \
    -e '/check_invisible/d'
 )
 #
 echo_eval bin/check_invisible.sh
+if [ "$skip_check_copy" == 'no' ]
+then
+   echo_eval bin/check_copy.sh
+fi
 for check in $list
 do
    echo_log_eval $check
@@ -345,7 +366,7 @@ echo_log_eval tar -xzf cppad-$version.tgz
 echo_log_eval cd cppad-$version
 #
 # build/cppad-$version/bin/get_optional.sh
-sed -i bin/get_optional.sh -e "s|^prefix=.*|prefix=$prefix|"
+$sed -i bin/get_optional.sh -e "s|^prefix=.*|prefix=$prefix|"
 #
 # builder
 if [ "$use_configure" == 'yes' ]
@@ -417,8 +438,8 @@ cd build
 program='example/print_for/example_print_for'
 echo_log_eval $builder -j $n_job example_print_for
 echo_log_eval $program
-$program | sed -e '/^Test passes/,$d' > temp.1.$$
-$program | sed -e '1,/^Test passes/d' > temp.2.$$
+$program | $sed -e '/^Test passes/,$d' > temp.1.$$
+$program | $sed -e '1,/^Test passes/d' > temp.2.$$
 if diff temp.1.$$ temp.2.$$
 then
    rm temp.1.$$ temp.2.$$
@@ -439,7 +460,7 @@ fi
 #
 #
 echo "date >> check_all.log"
-date  | sed -e 's|^|date: |' >> $top_srcdir/check_all.log
+date  | $sed -e 's|^|date: |' >> $top_srcdir/check_all.log
 # ----------------------------------------------------------------------------
 echo "$0: OK" >> $top_srcdir/check_all.log
 echo "$0: OK"
