@@ -2,7 +2,7 @@
 # define CPPAD_CORE_DEPENDENT_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-24 Bradley M. Bell
+// SPDX-FileContributor: 2003-25 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 {xrst_begin Dependent}
@@ -136,7 +136,7 @@ Different versions of Dependent function.
 */
 
 /*!
-Determine the tape corresponding to this exeuction thread and then use
+Determine the tape corresponding to this execution thread and then use
 <code>Dependent(tape, y)</code> to store this tapes recording in a function.
 
 \param y [in]
@@ -158,7 +158,7 @@ void ADFun<Base,RecBase>::Dependent(const ADvector &y)
 
 
 /*!
-Determine the tape corresponding to this exeuction thread and then use
+Determine the tape corresponding to this execution thread and then use
 <code>Dependent(tape, y)</code> to store this tapes recording in a function.
 
 \param x [in]
@@ -275,16 +275,16 @@ void ADFun<Base,RecBase>::Dependent(local::ADTape<Base> *tape, const ADvector &y
    num_order_taylor_          = 0;
    cap_order_taylor_          = 0;
    num_direction_taylor_      = 0;
-   num_var_tape_              = tape->Rec_.num_var_rec();
+   num_var_tape_              = tape->Rec_.num_var();
 
    // taylor_
    taylor_.resize(0);
 
    // cskip_op_
-   cskip_op_.resize( tape->Rec_.num_op_rec() );
+   cskip_op_.resize( tape->Rec_.num_var_op() );
 
    // load_op2var_
-   load_op2var_.resize( tape->Rec_.num_var_load_rec() );
+   load_op2var_.resize( tape->Rec_.num_var_load() );
 
    // play_
    // Now that each dependent variable has a place in the tape,
@@ -309,8 +309,8 @@ void ADFun<Base,RecBase>::Dependent(local::ADTape<Base> *tape, const ADvector &y
    subgraph_info_.resize(
       ind_taddr_.size(),   // n_dep
       dep_taddr_.size(),   // n_ind
-      play_.num_op_rec(),  // n_op
-      play_.num_var_rec()  // n_var
+      play_.num_var_op(),  // n_op
+      play_.num_var()      // n_var
    );
    // ---------------------------------------------------------------------
    // End set ad_fun.hpp private member data
@@ -319,8 +319,8 @@ void ADFun<Base,RecBase>::Dependent(local::ADTape<Base> *tape, const ADvector &y
    // now we can delete the tape
    AD<Base>::tape_manage(delete_tape_manage);
 
-   // total number of varables in this recording
-   CPPAD_ASSERT_UNKNOWN( num_var_tape_  == play_.num_var_rec() );
+   // total number of variables in this recording
+   CPPAD_ASSERT_UNKNOWN( num_var_tape_  == play_.num_var() );
 
    // used to determine if there is an operation sequence in *this
    CPPAD_ASSERT_UNKNOWN( num_var_tape_  > 0 );
