@@ -2,7 +2,7 @@
 # define CPPAD_CORE_STD_MATH_11_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-24 Bradley M. Bell
 // ----------------------------------------------------------------------------
 /*
 -------------------------------------------------------------------------------
@@ -13,7 +13,7 @@ Inverse Cosine Function: acos
 
 Syntax
 ******
-*y* = ``acos`` ( *x* )
+| *y* = ``acos`` ( *x* )
 
 x, y
 ****
@@ -181,9 +181,6 @@ contains an example and test of this function.
 {xrst_end atan}
 -------------------------------------------------------------------------------
 {xrst_begin atanh}
-{xrst_spell
-   tanh
-}
 The Inverse Hyperbolic Tangent Function: atanh
 ##############################################
 
@@ -725,8 +722,8 @@ It then uses this function to define Name(x) where x has type
 AD<Base> or VecAD_reference<Base>.
 
 If x is a variable, the tape unary operator Op is used
-to record the operation and the result is identified as correspoding
-to this operation; i.e., Name(x).taddr_ idendifies the operation and
+to record the operation and the result is identified as corresponding
+to this operation; i.e., Name(x).taddr_ identifies the operation and
 Name(x).tape_id_ identifies the tape.
 
 This macro is used to define AD<Base> versions of
@@ -830,7 +827,7 @@ namespace CppAD {
          if( complement )
             op = local::erfc_dyn;
 
-           // dynamic paramter argument
+           // dynamic parameter argument
          result.taddr_   = tape->Rec_.put_dyn_par(
             result.value_, op, taddr_
          );
@@ -838,7 +835,7 @@ namespace CppAD {
          result.ad_type_  = dynamic_enum;
       }
       else
-      {  local::OpCode op = local::ErfOp;
+      {  local::op_code_var op = local::ErfOp;
          if( complement )
             op = local::ErfcOp;
 
