@@ -2,7 +2,7 @@
 # define CPPAD_LOCAL_INDEPENDENT_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-24 Bradley M. Bell
+// SPDX-FileContributor: 2003-25 Bradley M. Bell
 // ----------------------------------------------------------------------------
 namespace CppAD { namespace local { //  BEGIN_CPPAD_LOCAL_NAMESPACE
 /*
@@ -44,17 +44,17 @@ void ADTape<Base>::Independent(
    size_t n = x.size();
    CPPAD_ASSERT_KNOWN(
       n > 0,
-      "Indepdendent: the argument vector x has zero size"
+      "Independent: the argument vector x has zero size"
    );
-   CPPAD_ASSERT_UNKNOWN( Rec_.num_var_rec() == 0 );
+   CPPAD_ASSERT_UNKNOWN( Rec_.num_var() == 0 );
    CPPAD_ASSERT_UNKNOWN( Rec_.get_abort_op_index() == 0 );
    CPPAD_ASSERT_UNKNOWN( Rec_.get_record_compare() == true );
-   CPPAD_ASSERT_UNKNOWN( Rec_.get_num_dynamic_ind()    == 0 );
+   CPPAD_ASSERT_UNKNOWN( Rec_.n_dyn_independent()    == 0 );
 
    // set record_compare and abort_op_index before doing anything else
    Rec_.set_record_compare(record_compare);
    Rec_.set_abort_op_index(abort_op_index);
-   Rec_.set_num_dynamic_ind( dynamic.size() );
+   Rec_.set_n_dyn_independent( dynamic.size() );
 
    // mark the beginning of the tape and skip the first variable index
    // (zero) because parameters use taddr zero
@@ -88,8 +88,8 @@ void ADTape<Base>::Independent(
 
    // Place independent dynamic parameters at beginning of parameter vector,
    // just after the nan at index zero.
-   CPPAD_ASSERT_UNKNOWN( Rec_.get_num_dynamic_ind() <= dynamic.size() );
-   for(size_t j = 0; j < Rec_.get_num_dynamic_ind(); ++j)
+   CPPAD_ASSERT_UNKNOWN( Rec_.n_dyn_independent() <= dynamic.size() );
+   for(size_t j = 0; j < Rec_.n_dyn_independent(); ++j)
    {  CPPAD_ASSERT_UNKNOWN( ! Dynamic( dynamic[j] ) );
       CPPAD_ASSERT_UNKNOWN( Parameter( dynamic[j] ) );
       //
