@@ -2,12 +2,12 @@
 # define  CPPAD_LOCAL_VAL_GRAPH_FOLD_CON_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2023-24 Bradley M. Bell
+// SPDX-FileContributor: 2023-25 Bradley M. Bell
 /*
 -------------------------------------------------------------------------------
 {xrst_begin val_tape_fold_con dev}
 {xrst_spell
-  dep
+   dep
 }
 
 Constant Folding
@@ -91,7 +91,7 @@ void tape_t<Value>::fold_con(void)
    bool trace           = false;
    eval(trace, val_index2con);
    //
-   // is_consant
+   // is_constant
    vectorBool is_constant( static_cast<size_t>(n_val_) );
    for(addr_t i = 0; i < n_val_; ++i)
       is_constant[i] = false;
@@ -135,8 +135,8 @@ void tape_t<Value>::fold_con(void)
       op_enum_t  op_enum   = op_ptr->op_enum();
       addr_t     n_before  = op_ptr->n_before();
       addr_t     n_after   = op_ptr->n_after();
-      addr_t     n_arg     = op_ptr->n_arg(arg_index, arg_vec_);
-      addr_t     n_res     = op_ptr->n_res(arg_index, arg_vec_);
+      addr_t     n_arg     = op_ptr->n_arg(arg_index, var_arg_);
+      addr_t     n_res     = op_ptr->n_res(arg_index, var_arg_);
       //
       CPPAD_ASSERT_UNKNOWN( size_t( res_index ) == old2new_index.size() );
       //
@@ -144,7 +144,7 @@ void tape_t<Value>::fold_con(void)
       if( n_res == 1 && op_enum != con_op_enum )
       {  bool fold = true;
          for(addr_t i = n_before; i < n_arg - n_after; ++i)
-            fold &= is_constant[ arg_vec_[arg_index + i] ];
+            fold &= is_constant[ var_arg_[arg_index + i] ];
          if( fold )
          {  is_constant[res_index]  = true;
             const Value& value      = val_index2con[res_index];
@@ -154,14 +154,14 @@ void tape_t<Value>::fold_con(void)
          else
          {  op_arg.resize(n_arg);
             for(addr_t k = 0; k < n_before; ++k)
-               op_arg[k] = arg_vec_[arg_index + k];
+               op_arg[k] = var_arg_[arg_index + k];
             for(addr_t k = n_before; k < n_arg - n_after; ++k)
-            {  addr_t old_index = arg_vec_[arg_index + k];
+            {  addr_t old_index = var_arg_[arg_index + k];
                assert( old_index < res_index );
                op_arg[k] = old2new_index[old_index];
             }
             for(addr_t k = 1; k <= n_after; ++k)
-               op_arg[n_arg - k] = arg_vec_[arg_index + n_arg - k];
+               op_arg[n_arg - k] = var_arg_[arg_index + n_arg - k];
             //
             addr_t new_res_index = new_tape.record_op(op_enum, op_arg);
             old2new_index.push_back( new_res_index );
@@ -190,8 +190,8 @@ void tape_t<Value>::fold_con(void)
          case call_op_enum:
          {  //
             // atomic_index, call_id
-            addr_t atomic_index = arg_vec_[arg_index + 2];
-            addr_t call_id      = arg_vec_[arg_index + 3];
+            addr_t atomic_index = var_arg_[arg_index + 2];
+            addr_t call_id      = var_arg_[arg_index + 3];
             CPPAD_ASSERT_UNKNOWN( atomic_index > 0 );
             //
             // n_before, n_x
@@ -201,7 +201,7 @@ void tape_t<Value>::fold_con(void)
             type_x.resize(n_x);
             con_x.resize(n_x);
             for(addr_t i = 0; i < n_x; ++i)
-            {  addr_t val_index =  arg_vec_[arg_index + n_before + i];
+            {  addr_t val_index =  var_arg_[arg_index + n_before + i];
                con_x[i] = val_index2con[val_index];
                if( is_constant[val_index] )
                   type_x[i] = constant_enum;
@@ -219,7 +219,7 @@ void tape_t<Value>::fold_con(void)
             // record the function call
             op_arg.resize(n_x);
             for(addr_t k = 0; k < n_x; ++k)
-            {  addr_t old_index   = arg_vec_[arg_index + n_before + k];
+            {  addr_t old_index   = var_arg_[arg_index + n_before + k];
                op_arg[k]      = old2new_index[old_index];
             }
             addr_t new_res_index = new_tape.record_call_op(
