@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-25 Bradley M. Bell
+// SPDX-FileContributor: 2025 Perry de Valpine
 // ----------------------------------------------------------------------------
 
 /*
@@ -10,6 +11,90 @@ Old examples now just used for validation testing.
 
 namespace { // BEGIN empty namespace
 
+// ---------------------------------------------------------------------------
+// dynamic_zero
+// Cases during recording where the base or exponent is a dynamic parameter
+// with value zero.
+bool dynamic_zero(void)
+{  bool ok = true;
+   using CppAD::AD;
+   using CppAD::NearEqual;
+   double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
+
+   const size_t nd = 1, nx = 1, ny = 1;
+   size_t abort_op_index = 0;
+   bool   record_compare = false;
+   // -----------------------------
+   // Case A: x = variable, y = dynamic; y == 0 during recording
+   // -----------------------------
+   {
+      CPPAD_TESTVECTOR(AD<double>) ax(nx), ay(ny), adyn(nd);
+      ax[0]  = 2.0;      // x during recording
+      adyn[0]= 0.0;      // y during recording (dynamic zero)
+
+      CppAD::Independent(ax, abort_op_index, record_compare, adyn);
+
+      AD<double> x = ax[0];
+      AD<double> y = adyn[0]; // dynamic param (zero)
+      ay[0] = pow(x, y);      // variable ^ dynamic 0
+
+      CppAD::ADFun<double> f(ax, ay);
+
+      // Evaluate with new dynamic values
+      CPPAD_TESTVECTOR(double) x_in(nx), y_out(ny), dyn(nd);
+
+      // First eval: y = 3 (non-zero), x = 2 => 2^3 = 8
+      x_in[0] = 2.0;
+      dyn[0]  = 3.0;
+      f.new_dynamic(dyn);
+      y_out = f.Forward(0, x_in);
+      ok &= NearEqual(y_out[0], 8.0, eps99, eps99);
+
+      // Second eval: y = 2, x = 3 => 3^2
+      x_in[0] = 3.0;
+      dyn[0]  = 2.0;
+      f.new_dynamic(dyn);
+      y_out = f.Forward(0, x_in);
+      ok &= NearEqual(y_out[0], std::pow(3.0, 2.0), eps99, eps99);
+   }
+
+   // -----------------------------
+   // Case B: x = dynamic (zero at recording), y = variable
+   // -----------------------------
+   {
+      CPPAD_TESTVECTOR(AD<double>) ax(nx), ay(ny), adyn(nd);
+      ax[0]   = 3.0;     // y during recording
+      adyn[0] = 0.0;     // x during recording (dynamic zero)
+
+      CppAD::Independent(ax, abort_op_index, record_compare, adyn);
+
+      AD<double> x = adyn[0]; // dynamic param (zero)
+      AD<double> y = ax[0];   // variable
+      ay[0] = pow(x, y);      // dynamic 0 ^ variable
+
+      CppAD::ADFun<double> f(ax, ay);
+
+      // Evaluate with new dynamic values
+      CPPAD_TESTVECTOR(double) x_in(nx), y_out(ny), dyn(nd);
+
+      // First eval: x = 2 (non-zero), y = 3 => 2^3 = 8
+      x_in[0] = 3.0;  // y
+      dyn[0]  = 2.0;  // x
+      f.new_dynamic(dyn);
+      y_out = f.Forward(0, x_in);
+      ok &= NearEqual(y_out[0], 8.0, eps99, eps99);
+
+      // Second eval: x = 3, y = 2 => 3^2
+      x_in[0] = 2.0;  // y
+      dyn[0]  = 3.0;  // x
+      f.new_dynamic(dyn);
+      y_out = f.Forward(0, x_in);
+      ok &= NearEqual(y_out[0], std::pow(3.0, 2.0), eps99, eps99);
+   }
+
+   return ok;
+}
+// ---------------------------------------------------------------------------
 bool PowTestOne(void)
 {  bool ok = true;
 
@@ -605,6 +690,7 @@ bool PowTestTen(void)
 
 bool Pow(void)
 {  bool ok = true;
+   ok     &= dynamic_zero();
    ok     &= PowTestOne();
    ok     &= PowTestTwo();
    ok     &= PowTestThree();
